# jgtml
__version__ = '0.0.3'
import sys
import os

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

from calc import calculate_target_variable_min_max as calc_targets

#from jgtpy import JGTPDS as pds,JGTADS as ads,JGTPDSP as pds
